@@ -49,6 +49,7 @@
 #include "debug.hpp"
 #include "sharp/exception.hpp"
 #include "sharp/files.hpp"
+#include "sharp/map.hpp"
 #include "sharp/string.hpp"
 #include "sharp/xmlconvert.hpp"
 #include "sharp/xmlwriter.hpp"
@@ -61,17 +62,21 @@ namespace gnote {
     void show_deletion_dialog (const std::list<Note::Ptr> & notes, Gtk::Window * parent)
     {
       std::string message;
-      
-      if (notes.size() == 1)
-        message = _("Really delete this note?");
-      else
-        message = str(boost::format(_("Really delete these %1% notes?")) % notes.size());
-      
+
+      // %1% is the number of note.
+      message = ngettext("Really delete this note?", "Really delete these %1% notes?", notes.size());
+
+      boost::format format(message);
+      // make sure an exception is not raised for the non-plural form
+      format.exceptions( boost::io::all_error_bits ^ 
+                         ( boost::io::too_many_args_bit | 
+                           boost::io::too_few_args_bit )  );
+
       utils::HIGMessageDialog dialog(parent, GTK_DIALOG_DESTROY_WITH_PARENT,
-              Gtk::MESSAGE_QUESTION,
-              Gtk::BUTTONS_NONE,
-              message,
-              _("If you delete a note it is permanently lost."));
+                                     Gtk::MESSAGE_QUESTION,
+                                     Gtk::BUTTONS_NONE,
+                                     str(format % notes.size()),
+                                     _("If you delete a note it is permanently lost."));
 
       Gtk::Button *button;
 
@@ -662,17 +667,30 @@ namespace gnote {
 
   void Note::remove_tag(Tag & tag)
   {
+    std::string tag_name = tag.normalized_name();
     NoteData::TagMap & thetags(m_data.data().tags());
-    NoteData::TagMap::iterator iter = thetags.find(tag.normalized_name());
-    if (iter == thetags.end())
-      return;
+    NoteData::TagMap::iterator iter;
+
+    // if we are deleting the note, no need to check for the tag, we 
+    // know it is there.
+    if(!m_is_deleting) {
+      iter = thetags.find(tag_name);
+      if (iter == thetags.end())  {
+        return;
+      }
+    }
 
     m_signal_tag_removing(*this, tag);
 
-    thetags.erase(iter);
+    // don't erase the tag if we are deleting the note. 
+    // This will invalidate the iterator.
+    // see bug 579839.
+    if(!m_is_deleting) {
+      thetags.erase(iter);
+    }
     tag.remove_note(*this);
 
-    m_signal_tag_removed(shared_from_this(), tag.normalized_name());
+    m_signal_tag_removed(shared_from_this(), tag_name);
 
     DBG_OUT("Tag removed, queueing save");
     queue_save(OTHER_DATA_CHANGED);
@@ -1053,10 +1071,7 @@ namespace gnote {
   
   void Note::get_tags(std::list<Tag::Ptr> & l) const
   {
-    for(NoteData::TagMap::const_iterator iter = m_data.data().tags().begin();
-        iter != m_data.data().tags().end(); ++iter) {
-      l.push_back(iter->second);
-    }
+    sharp::map_get_values(m_data.data().tags(), l);
   }
 
   const char *NoteArchiver::CURRENT_VERSION = "0.3";
@@ -1284,7 +1299,7 @@ namespace gnote {
     }
 
     xml.write_start_element("", "open-on-startup", "");
-    xml.write_string(boost::lexical_cast<std::string>(note.is_open_on_startup()));
+    xml.write_string(note.is_open_on_startup() ? "True" : "False");
     xml.write_end_element();
 
     xml.write_end_element(); // Note
